@@ -18,11 +18,11 @@
 #' error.  The latter is useful for nested models or for models with a tuning 
 #' parameter controlling the complexity of the model (e.g., penalized 
 #' regression).  It selects the most parsimonious model whose prediction error 
-#' is no larger than \code{sdFactor} standard errors above the prediction error 
+#' is no larger than \code{seFactor} standard errors above the prediction error 
 #' of the best overall model.  Note that the models are thereby assumed to be 
 #' ordered from the most parsimonious one to the most complex one.  In 
 #' particular a one-standard-error rule is frequently applied.
-#' @param sdFactor  a numeric value giving a multiplication factor of the 
+#' @param seFactor  a numeric value giving a multiplication factor of the 
 #' standard error for the selection of the best model.  This is ignored if 
 #' \code{selectBest} is \code{"min"}.
 #' @param \dots  additional arguments to be passed down.
@@ -38,11 +38,11 @@
 #' @returnItem cv  a data frame containing the estimated prediction errors for 
 #' the models.  For repeated cross-validation, those are average values over 
 #' all replications.
-#' @returnItem sd  a data frame containing the estimated standard errors of the 
+#' @returnItem se  a data frame containing the estimated standard errors of the 
 #' prediction loss for the models.
 #' @returnItem selectBest  a character string specifying the criterion used for 
 #' selecting the best model.
-#' @returnItem sdFactor  a numeric value giving the multiplication factor of 
+#' @returnItem seFactor  a numeric value giving the multiplication factor of 
 #' the standard error used for the selection of the best model.
 #' @returnItem reps  a data frame containing the estimated prediction errors 
 #' for the models from all replications.  This is only returned if repeated 
@@ -69,7 +69,7 @@ cvReshape <- function(x, ...) UseMethod("cvReshape")
 #' @method cvReshape cv
 #' @export
 cvReshape.cv <- function(x, 
-        selectBest = c("min", "hastie"), sdFactor = 1, ...) {
+        selectBest = c("min", "hastie"), seFactor = 1, ...) {
     # initializations
     if(ncv(x) == 0 || isTRUE(nfits(x) == 0)) stop("empty object")
     cvNames <- cvNames(x)
@@ -89,7 +89,7 @@ cvReshape.cv <- function(x,
     # call cvSelect() to combine the model fits
     names(objects) <- cvNames
     objects$.selectBest <- selectBest
-    objects$.sdFactor <- sdFactor
+    objects$.seFactor <- seFactor
     out <- do.call(cvSelect, objects)
     if(length(out$K) > 1) out$K <- out$K[1]
     if(length(out$R) > 1) out$R <- out$R[1]
